#include <Evas.h>
#include <Ecore.h>
#include <Ecore_Evas.h>
#include <Emotion.h>

Evas_Object *background;
Evas_Object *video;

/* if the window manager requests a delete - quit cleanly */
static void
canvas_delete_request(Ecore_Evas *ee)
{
   ecore_main_loop_quit();
}

/* if the canvas is resized - resize the video too */
static void
canvas_resize(Ecore_Evas *ee)
{
   Evas_Coord x, y, w, h;
   int vw, vh;
   double ratio;
   
   /* get the current canvas size */
   evas_output_viewport_get(ecore_evas_get(ee), NULL, NULL, &w, &h);

   /* resize the black background rectangle */
   evas_object_move(background, 0, 0);
   evas_object_resize(background, w, h);

   /* resize the video object AND retain aspect ratio */
   /* get the video size in pixels */
   emotion_object_size_get(video, &vw, &vh);
   /* get the video ratio */
   ratio = emotion_object_ratio_get(video);
   /* if the ratio > 0.0 then the video wants awidth / height ratio on the */
   /* screen as returned indicated by this ratio value. this is irrespective */
   /* of the pixel size of the video and indicates the video wants to scale */
   if (ratio > 0.0)
     {
	x = 0;
	y = (h - (w / ratio)) / 2;
	if (y < 0)
	  {
	     y = 0;
	     x = (w - (h * ratio)) / 2;
	     w = h * ratio;
	  }
	else
	  h = w / ratio;
	evas_object_move(video, x, y);
	evas_object_resize(video, w, h);
     }
   else
     {
	if (vh > 0)
	  /* generate ratio from the pixel size */
	  ratio = (double)vw / (double)vh;
	else
	  ratio = 1.0;
	x = 0;
	y = (h - (w / ratio)) / 2;
	if (y < 0)
	  {
	     y = 0;
	     x = (w - (h * ratio)) / 2;
	     w = h * ratio;
	  }
	else
	  h = w / ratio;
	evas_object_move(video, 0, 0);
	evas_object_resize(video, w, h);
     }
}

/* the main function of the program */
int main(int argc, char **argv)
{
   Ecore_Evas *ee;
   char *file = "dvd:/";
   
   /* if the first argument exists, use it as the file to play */
   if (argc > 1) file = argv[1];
   
   /* create a canvas, display it, set a title, callbacks to call on resize */
   /* or if the window manager asks it to be deleted */
   ecore_evas_init();
   ee = ecore_evas_software_x11_new(NULL, 0, 0, 0, 800, 600);
   ecore_evas_callback_delete_request_set(ee, canvas_delete_request);
   ecore_evas_callback_resize_set(ee, canvas_resize);   
   ecore_evas_title_set(ee, "My DVD Player");
   ecore_evas_name_class_set(ee, "my_dvd_player", "My_DVD_Player");
   ecore_evas_show(ee);

   /* create a black background object */
   background = evas_object_rectangle_add(ecore_evas_get(ee));
   evas_object_color_set(background, 0, 0, 0, 255);
   evas_object_show(background);
   
   /* create a video object */
   video = emotion_object_add(ecore_evas_get(ee));
   emotion_object_file_set(video, file);
   emotion_object_play_set(video, 1);
   evas_object_show(video);

   /* force an initial resize */
   canvas_resize(ee);
   
   /* run the main loop of the program - playing, drawing, handling events */
   ecore_main_loop_begin();
   
   /* if we exit the main loop we will shut down */
   ecore_evas_shutdown();
}
